@@ -1,5 +1,5 @@
 package GeoIP2::Database::Reader;
-$GeoIP2::Database::Reader::VERSION = '0.040003';
+$GeoIP2::Database::Reader::VERSION = '0.040004';
 use strict;
 use warnings;
 
@@ -7,10 +7,11 @@ use Carp qw( croak );
 use GeoIP2::Error::Generic;
 use GeoIP2::Error::IPAddressNotFound;
 use GeoIP2::Model::City;
-use GeoIP2::Model::CityISPOrg;
+use GeoIP2::Model::ConnectionType;
 use GeoIP2::Model::Country;
-use GeoIP2::Model::Omni;
-use GeoIP2::Model::Omni;
+use GeoIP2::Model::Domain;
+use GeoIP2::Model::Insights;
+use GeoIP2::Model::ISP;
 use GeoIP2::Types qw( Str );
 use MaxMind::DB::Reader;
 
@@ -22,6 +23,7 @@ has file => (
     is       => 'ro',
     isa      => Str,
     required => 1,
+    coerce   => sub { "$_[0]" },
 );
 
 has _reader => (
@@ -66,8 +68,13 @@ sub _model_for_address {
 
     my $model_class = 'GeoIP2::Model::' . $class;
 
-    $record->{traits} ||= {};
-    $record->{traits}{ip_address} = $ip;
+    if ( $args{is_flat} ) {
+        $record->{ip_address} = $ip;
+    }
+    else {
+        $record->{traits} ||= {};
+        $record->{traits}{ip_address} = $ip;
+    }
 
     return $model_class->new( %{$record}, locales => $self->locales, );
 }
@@ -79,7 +86,7 @@ sub city {
 
 sub city_isp_org {
     my $self = shift;
-    return $self->_model_for_address( 'CityISPOrg', @_ );
+    return $self->city(@_);
 }
 
 sub country {
@@ -87,9 +94,29 @@ sub country {
     return $self->_model_for_address( 'Country', @_ );
 }
 
+sub insights {
+    my $self = shift;
+    return $self->_model_for_address( 'Insights', @_ );
+}
+
 sub omni {
     my $self = shift;
-    return $self->_model_for_address( 'Omni', @_ );
+    return $self->insights(@_);
+}
+
+sub connection_type {
+    my $self = shift;
+    return $self->_model_for_address( 'ConnectionType', is_flat => 1, @_ );
+}
+
+sub domain {
+    my $self = shift;
+    return $self->_model_for_address( 'Domain', is_flat => 1, @_ );
+}
+
+sub isp {
+    my $self = shift;
+    return $self->_model_for_address( 'ISP', is_flat => 1, @_ );
 }
 
 1;
@@ -106,7 +133,7 @@ GeoIP2::Database::Reader - Perl API for GeoIP2 databases
 
 =head1 VERSION
 
-version 0.040003
+version 0.040004
 
 =head1 SYNOPSIS
 
@@ -125,22 +152,12 @@ version 0.040003
 
 =head1 DESCRIPTION
 
-This class provides a reader API for all GeoIP2 databases.  The methods
-provided by this reader (C<country()>, C<city()>, C<city_isp_org()> and
-C<omni()>), correspond to the web service endpoints (Country, City,
-City/ISP/Org, and Omni). Each method returns a different set of data about an
-IP address, with country returning the least data and omni the most.
-
-Each method returns a different model class, and these model classes in turn
-contain multiple record classes. The record classes have attributes which
-contain data about the IP address.
+This class provides a reader API for all GeoIP2 databases. Each method returns
+a different model class.
 
 If the database does not return a particular piece of data for an IP address,
 the associated attribute is not populated.
 
-The database may not return any information for an entire record, in which case
-all of the attributes for that record class will be empty.
-
 =head1 USAGE
 
 The basic API for this class is the same for all database types.  First you
@@ -149,8 +166,7 @@ Then you call the method corresponding to your database type, passing it the
 IP address you want to look up.
 
 If the request succeeds, the method call will return a model class for the
-method point you called. This model, in turn, contains multiple record classes,
-each of which represents part of the data returned by the database.
+method point you called.
 
 If the database cannot be read, the reader class throws an exception.
 
@@ -229,6 +245,10 @@ address.
 
 =back
 
+=head2 $reader->connection_type()
+
+This method returns a L<GeoIP2::Model::ConnectionType> object.
+
 =head2 $reader->country()
 
 This method returns a L<GeoIP2::Model::Country> object.
@@ -237,18 +257,22 @@ This method returns a L<GeoIP2::Model::Country> object.
 
 This method returns a L<GeoIP2::Model::City> object.
 
-=head2 $reader->city_isp_org()
+=head2 $reader->domain()
 
-This method returns a L<GeoIP2::Model::CityISPOrg> object.
+This method returns a L<GeoIP2::Model::Domain> object.
 
-=head2 $reader->omni()
+=head2 $reader->insights()
 
-This method returns a L<GeoIP2::Model::Omni> object.
+This method returns a L<GeoIP2::Model::Insights> object.
 
-Note that the data which makes the Omni web service different from
-City/ISP/Org is not available in any downloadable database. This means that
-calling the C<< $reader->omni() >> always returns the same data as as C<<
-$reader->city_isp_org() >>.
+Note that the data which makes the Insights web service different from
+City is not available in any downloadable database. This means that
+calling the C<< $reader->insights() >> always returns the same data as as C<<
+$reader->city() >>.
+
+=head2 $reader->isp()
+
+This method returns a L<GeoIP2::Model::ISP> object.
 
 =head1 EXCEPTIONS
 
@@ -273,9 +297,6 @@ where some or all of the attributes are unpopulated.
 See L<http://dev.maxmind.com/geoip/geoip2/web-services> for details on what
 data each end point I<may> return.
 
-The only piece of data which is always returned is the C<ip_address> key in
-the C<GeoIP2::Record::Traits> record.
-
 Every record class attribute has a corresponding predicate method so you can
 check to see if the attribute is set.
 
@@ -297,10 +318,6 @@ Olaf Alders <oalders@maxmind.com>
 
 =back
 
-=head1 CONTRIBUTOR
-
-Graham Knop <haarg@haarg.org>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by MaxMind, Inc..
