@@ -1,5 +1,5 @@
 package GeoIP2::Error::Type;
-$GeoIP2::Error::Type::VERSION = '0.040003';
+$GeoIP2::Error::Type::VERSION = '0.040004';
 use strict;
 use warnings;
 
@@ -33,7 +33,7 @@ GeoIP2::Error::Type - A type validation error.
 
 =head1 VERSION
 
-version 0.040003
+version 0.040004
 
 =head1 SYNOPSIS
 
@@ -99,10 +99,6 @@ Olaf Alders <oalders@maxmind.com>
 
 =back
 
-=head1 CONTRIBUTOR
-
-Graham Knop <haarg@haarg.org>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by MaxMind, Inc..
