@@ -1,5 +1,5 @@
 package GeoIP2::Error::WebService;
-$GeoIP2::Error::WebService::VERSION = '0.040003';
+$GeoIP2::Error::WebService::VERSION = '0.040004';
 use strict;
 use warnings;
 
@@ -31,7 +31,7 @@ GeoIP2::Error::WebService - An explicit error from the GeoIP2 web service
 
 =head1 VERSION
 
-version 0.040003
+version 0.040004
 
 =head1 SYNOPSIS
 
@@ -106,10 +106,6 @@ Olaf Alders <oalders@maxmind.com>
 
 =back
 
-=head1 CONTRIBUTOR
-
-Graham Knop <haarg@haarg.org>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by MaxMind, Inc..
