@@ -1,5 +1,5 @@
 package GeoIP2::Record::City;
-$GeoIP2::Record::City::VERSION = '0.040003';
+$GeoIP2::Record::City::VERSION = '0.040004';
 use strict;
 use warnings;
 
@@ -35,7 +35,7 @@ GeoIP2::Record::City - Contains data for the city record associated with an IP a
 
 =head1 VERSION
 
-version 0.040003
+version 0.040004
 
 =head1 SYNOPSIS
 
@@ -68,7 +68,7 @@ This class provides the following methods:
 This returns a value from 0-100 indicating MaxMind's confidence that the city
 is correct.
 
-This attribute is only available from the Omni end point.
+This attribute is only available from the Insights end point.
 
 =head2 $city_rec->geoname_id()
 
@@ -114,10 +114,6 @@ Olaf Alders <oalders@maxmind.com>
 
 =back
 
-=head1 CONTRIBUTOR
-
-Graham Knop <haarg@haarg.org>
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2014 by MaxMind, Inc..
